@@ -93,7 +93,7 @@ TwopFeedbackModel<- function
             t_end
           )
       }
-      if(class(In)=="data.frame"){
+      if(inherits(In, "data.frame")){
          x=In[,1]  
          y=In[,2]  
          inputFlux=splinefun(x,y)
@@ -107,7 +107,7 @@ TwopFeedbackModel<- function
       A[2,1]=a21
       A[1,2]=a12
       if(length(xi)==1) fX=function(t){xi}
-      if(class(xi)=="data.frame"){
+      if(inherits(xi, "data.frame")){
         X=xi[,1]
         Y=xi[,2]
         fX=function(t){as.numeric(spline(X,Y,xout=t)[2])}
